import * as ec2 from '@aws-cdk/aws-ec2';
import * as cdk from '@aws-cdk/core';
/**
 * Construct properties for the EKS-D cluster.
 *
 * @stability stable
 */
export interface ClusterProps {
    /**
     * VPC for the cluster.
     *
     * @default - get or create a VPC
     * @stability stable
     */
    readonly vpc?: ec2.IVpc;
    /**
     * The default EC2 instance type.
     *
     * @default t3.large
     * @stability stable
     */
    readonly defaultInstanceType?: ec2.InstanceType;
    /**
     * number of instances.
     *
     * @default 1
     * @stability stable
     */
    readonly capacitySize?: number;
    /**
     * AMI for the EKS-D instance node.
     *
     * @default - The latest AMI from ubuntu-focal-20.04-amd64-server
     * @stability stable
     */
    readonly machineImage?: ec2.IMachineImage;
    /**
     * Print AMI ID in the output.
     *
     * @default - true
     * @stability stable
     */
    readonly outputAmiId?: boolean;
}
/**
 * Represents the EKS-D cluster.
 *
 * @stability stable
 */
export declare class Cluster extends cdk.Construct {
    private readonly defaultInstanceType;
    private readonly defaultCapacitySize;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props?: ClusterProps);
}
/**
 * The AMI provider to get the latest Ubuntu Linux AMI.
 *
 * @stability stable
 */
export declare class UbumtuAmiProvider {
    readonly scope: cdk.Construct;
    readonly userData: ec2.UserData;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, userData: ec2.UserData);
    /**
     * @stability stable
     */
    get amiId(): ec2.IMachineImage;
}
